to 2018-07-14 1500 XXX001 test against dob-init empty store
to 1500 XXX001 test against my existing store ending before 2018-07-14 1500
FIXME: Also need to test after existing store with closed final fact
- opening with ``to 1500`` (and given the facts that follow)
    only works on db with final ongoing fact ending before 2018-07-14 1500
  otherwise need to be explicit...
at 1500 XXX001.2 

to 2200

to 0123

to 2018-07-15 19:17: XXX002

XXX002, too

to 2018-07-15 21:55 XXX003, XXX004

to 2018-07-16 02:42: Act!i∷vi“@”tyyyy, #XXXX!005, #XXX:006 X#XXX006 #XXX@007: #DESC008@
DESC008.2

to +10: XXX009

to 2018-07-16 08:38: XXX010

at 2018-07-16 1000: XXX011

from 2010 to 2050 

00:27:59 to 2018-07-18 01:01: DESC012 [2018-07-18 01:18]

at 0920 desc013, desc014: desc015!

to 1120 desc016

from 1845 to 2018-07-19 02:47 desc017

then: desc018

from -20 to -5 desc019

at 2018-07-19 10:33 desc020

from -20 to -10 desc021

from -10 to 2018-07-19 14:18 desc022

1730 to 1745 desc023

to 2018-07-20 01:17 desc024 desc025, desc026

to 12:51 desc027

to -70: #tag028 #tag029 #tag030 030#tag: desc031

to -40 desc032.:

at 2018-07-20 20:20: desc033...

to -60 foo bar.

from -7 to 2018-07-21 16:15 baz bat

+0 desc0036

at 17:46:52 XXX

from 01:19:25 to 2018-07-22 01:31 ketchup
more desc

to +1: desc desc.

from 2018-07-31 0910 to 2018-07-31 13:29 desc0XXX test clock time to clock:time

from -40 to 2018-07-31 15:08 to desc0XXX

to 2018-08-07 17:41: #TAG041-DESC041-XXX, #DESC0042, DESC.

from -15 to 2018-08-07 18:14: desc, desc: desc desc to desc #desc @desc.

to 2018-08-08 04:16: #TAG-0051 #0052-TAG
desc desc desc

to 2018-08-10 00:26: desc

from 0816 to 0920 desc

0920 to 0930 desc

to 0940 desc

from 0915 to 0925 desc

to 0945 desc

after: desc

at 2018-08-13 10:09: #TAGSSS: [DESC]

to 2100: desc.

then: desc!

to 2018-08-15 0745: done.

to 2018-08-16 00:06 desc desc desc.

then: descccc descr

from 2018-08-16 0840 to 2018-08-16 0940 desc00099 desc00100

to 2018-08-24 18:27 dob dob dob

then: dob nark dob

from -45 to 2018-08-24 20:55 dobbin

to 0100 narkin

2018-08-28 00:03 desc

at 2018-09-11 22:48: desc

to 2018-09-12 00:31: desc

then: desccc

from 0050 to 2018-09-12 07:28: descc

to 0855: desc

to 1730: desc

to -20: desc

from -20 to -10: desc

from -10 to 2018-09-12 20:35: desc

then: desc

to 2018-09-12 23:50: desc

then: desc

at 2018-09-13 00:13: desc

to 2018-09-13 06:59: desc

at 2018-09-19 12:41: desc

to 2018-09-19 12:59: #tag-test-1 #tags test 2 #tag test@#!: desc tags added/squashed with first 'at' fact

then: 2018-09-19 12:41: #tag-test-3 should get added to list including previous

to 13:00: #tag- fourth tag to be added: desc

at 19:00

to 02:44

Different test possible for final fact
then: XXX-ongoing-1 [2019-01-22 22:10: works; ongoing]
to 0800 XXX-closed-1 [2019-01-22 22:12: works: closed]
at 0800 XXX-ongoing-2 [2019-01-22 22:12: works: ongoing]

at 0800 XXX-ongoing-2

